==> jmb.cms-misc-0.2.8.tar.gz: jmb.cms-misc-0.2.8/jmb/cms/contact_form/cms/models.py <==
from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pluginmodel import CMSPlugin
from django.conf import settings

class ContactSettings(CMSPlugin):
    slug = models.SlugField(
        max_length=100,
        null= True, blank=True
    )
    classes = models.CharField(
        max_length=100,
        null= True, blank=True
    )
    form = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_FORM_CLASSES,
        default="jmb.cms.contact_form.cms.forms.ContactForm",
        # editable=len(settings.CONTACT_FORM_CMSPLUGIN_FORM_CLASSES)>1
    )
    site_email = models.EmailField(_('Indirizzo di destinazione delle mail'))
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
        default="sender@example.org",
    )
    thanks = models.CharField(_('Messaggio di conferma'), max_length=200)
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_FORM_TEMPLATES,
        default="invitation/cms_plugins/contact_form.html"
    )
    thanks_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_THANKS_TEMPLATES,
        default="invitation/cms_plugins/contact_thanks.html"
    )
    email_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_EMAIL_TEMPLATES,
        default="invitation/cms_plugins/cantact_email.html"
    )
    tracking_url = models.URLField(
        max_length=200,
        null=True, blank=True,
        verbose_name=_("Tracking URL"),
        help_text=_("(Optional) URL for redirection after successful submit. Insert here the full URL for "
                    "tracking (with params).")
    )

    def __unicode__(self):
        return self.form_template_name

    class Meta:
        app_label = "contact_form"

==> jmb.cms-misc-0.4.1.tar.gz: jmb.cms-misc-0.4.1/jmb/cms/contact_form/cms/models.py <==
from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pluginmodel import CMSPlugin
from django.conf import settings

class ContactSettings(CMSPlugin):
    slug = models.SlugField(
        max_length=100,
        null= True, blank=True
    )
    classes = models.CharField(
        max_length=100,
        null= True, blank=True
    )
    form = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_FORM_CLASSES,
        default="jmb.cms.contact_form.cms.forms.ContactForm",
        # editable=len(settings.CONTACT_FORM_CMSPLUGIN_FORM_CLASSES)>1
    )
    site_email = models.EmailField(_('Indirizzo di destinazione delle mail'))
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
        default="sender@example.org",
    )
    thanks = models.CharField(_('Messaggio di conferma'), max_length=200)
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_FORM_TEMPLATES,
        default="invitation/cms_plugins/contact_form.html"
    )
    thanks_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_THANKS_TEMPLATES,
        default="invitation/cms_plugins/contact_thanks.html"
    )
    email_template_name = models.CharField(
        max_length=100,
        choices=settings.CONTACT_FORM_CMSPLUGIN_EMAIL_TEMPLATES,
        default="invitation/cms_plugins/cantact_email.html"
    )
    tracking_url = models.URLField(
        max_length=200,
        null=True, blank=True,
        verbose_name=_("Tracking URL"),
        help_text=_("(Optional) URL for redirection after successful submit. insert here the full URL for "
                    "tracking (with params).")
    )

    def __unicode__(self):
        return self.form_template_name

    class Meta:
        app_label = "contact_form"
